
import {RcsbFvStructure} from "../../RcsbFvStructure/RcsbFvStructure";
import uniqid from "uniqid";
import {
    LoadMolstarInterface,
    LoadMolstarReturnType
} from "../../RcsbFvStructure/StructureViewers/MolstarViewer/MolstarActionManager";
import {ViewerProps} from "@rcsb/rcsb-molstar/build/src/viewer";
import {StructureViewer} from "../../RcsbFvStructure/StructureViewers/StructureViewer";
import {NullBehaviourObserver} from "../../RcsbFvStructure/StructureViewerBehaviour/NullBehaviour";
import {MolstarTools} from "../../RcsbFvStructure/StructureViewers/MolstarViewer/MolstarUtils/MolstarTools";
import getModelIdFromTrajectory = MolstarTools.getModelIdFromTrajectory;
import {RcsbFv3DCustomAbstract} from "../../RcsbFv3D/RcsbFv3DCustomAbstract";
import { TmMolstarManagerFactory } from "./TmMolstarManagerFactory";
import { RcsbFv3DCustomInterface } from "../../RcsbFv3D/RcsbFv3DCustom";

type ViewerPropertiesType = {viewerElement:string|HTMLElement,viewerProps:Partial<ViewerProps>};
type StructureViewerType = StructureViewer<LoadMolstarInterface<unknown,unknown>,LoadMolstarReturnType,ViewerPropertiesType>;

export class TmFv3DCustom extends RcsbFv3DCustomAbstract<LoadMolstarInterface<unknown,unknown>,LoadMolstarReturnType,{viewerElement:string|HTMLElement,viewerProps:Partial<ViewerProps>}> {

    protected viewer: StructureViewerType;
    protected currentLoadConfig: any;

    constructor(params: RcsbFv3DCustomInterface) {

        const elementId: string = params.elementId ?? uniqid("TmDetFv3D_");
        const viewer = new StructureViewer<
            LoadMolstarInterface<unknown,unknown>,
            LoadMolstarReturnType,
            ViewerPropertiesType
        >( new TmMolstarManagerFactory(getModelIdFromTrajectory) );
        const config = {
            elementId: elementId,
            structureConfig: {
                loadConfig: params.structurePanelConfig.loadConfig,
                structureViewerConfig:{
                    ...params.structurePanelConfig.structureViewerConfig,
                    viewerElement:RcsbFvStructure.componentId(elementId),
                }
            },
            sequenceConfig:{
                ...params.sequencePanelConfig,
            },
            structureViewer: viewer,
            structureViewerBehaviourObserver: new NullBehaviourObserver<LoadMolstarInterface<unknown,unknown>,LoadMolstarReturnType>(),
            cssConfig: params.cssConfig
        };

        super(config);

        this.viewer = viewer;
        this.currentLoadConfig = config.structureConfig.loadConfig;
    }

    public async updateConfig(config: { structurePanelConfig?: { loadConfig: any }; sequencePanelConfig?: Partial<any> }) {
        super.updateConfig(config);

        // TODO: something is wrong around clear/reset/load: shaking camera after update config
        await this.viewer.clear();
        this.viewer.resetCamera();
        await this.viewer.load(config.structurePanelConfig?.loadConfig);
    }
}
